;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "minions" "20260601.1513"
  "A minor-mode menu for the mode line."
  '((emacs  "28.1")
    (compat "31.0")
    (seq    "2.24"))
  :url "https://github.com/tarsius/minions"
  :commit "7ec2810c9b3019f8e379022b0ca7ce61e9e7c810"
  :revdesc "7ec2810c9b30"
  :keywords '("convenience")
  :authors '(("Jonas Bernoulli" . "emacs.minions@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.minions@jonas.bernoulli.dev")))
